:orphan:

Explanations
============

Explanation, or discussions, clarify and illuminate a particular topic. They broaden the documentation's coverage of a topic.

.. toctree::
    
    docs_structure
    conventions
    todo